@@ -49,16 +49,19 @@
 
 package com.openexchange.pop3.connect;
 
+import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
+import static com.openexchange.pop3.services.POP3ServiceRegistry.getServiceRegistry;
 import static com.openexchange.pop3.util.POP3StorageUtil.parseLoginDelaySeconds;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.io.PrintStream;
-import java.io.UnsupportedEncodingException;
 import java.net.InetAddress;
 import java.net.SocketTimeoutException;
+import java.nio.charset.UnsupportedCharsetException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Date;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -68,11 +71,16 @@ import javax.mail.Folder;
 import javax.mail.MessagingException;
 import javax.mail.internet.idn.IDNA;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
+import com.openexchange.log.audit.AuditLogService;
+import com.openexchange.log.audit.DefaultAttribute;
+import com.openexchange.log.audit.DefaultAttribute.Name;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.pop3.POP3ExceptionCode;
 import com.openexchange.pop3.POP3Provider;
 import com.openexchange.pop3.config.IPOP3Properties;
@@ -227,12 +235,13 @@ public final class POP3StoreConnector {
      * @param pop3Config The POP3 configuration providing credentials and server settings
      * @param pop3Properties Optional additional POP3 properties applied to POP3 session (may be <code>null</code>)
      * @param monitorFailedAuthentication <code>true</code> to monitor failed authentication; otherwise <code>false</code>
+     * @param accountId The account identifier
      * @param session The session providing user information
      * @param errorOnMissingUIDL <code>true</code> to throw an error on missing UIDL; otherwise <code>false</code> to ignore
      * @return A connected instance of {@link POP3Store}
      * @throws OXException If establishing a connected instance of {@link POP3Store} fails
      */
-    public static POP3StoreResult getPOP3Store(final POP3Config pop3Config, final Properties pop3Properties, final boolean monitorFailedAuthentication, final Session session, final boolean errorOnMissingUIDL, final boolean forceSecure) throws OXException {
+    public static POP3StoreResult getPOP3Store(POP3Config pop3Config, Properties pop3Properties, boolean monitorFailedAuthentication, int accountId, Session session, boolean errorOnMissingUIDL, boolean forceSecure) throws OXException {
         try {
             final boolean tmpDownEnabled = (POP3Properties.getInstance().getPOP3TemporaryDown() > 0);
             if (tmpDownEnabled) {
@@ -264,16 +273,9 @@ public final class POP3StoreConnector {
              * JavaMail POP3 implementation requires capabilities "UIDL" and "TOP"
              */
             final POP3StoreResult result = new POP3StoreResult(staticCapabilities);
-            final String login = pop3Config.getLogin();
+            String login = authEncode(pop3Config.getLogin(), POP3Properties.getInstance().getPOP3AuthEnc());
             boolean responseCodeAware = staticCapabilities.indexOf("RESP-CODES") >= 0;
-            String tmpPass = pop3Config.getPassword();
-            if (tmpPass != null) {
-                try {
-                    tmpPass = new String(tmpPass.getBytes(POP3Properties.getInstance().getPOP3AuthEnc()), com.openexchange.java.Charsets.ISO_8859_1);
-                } catch (final UnsupportedEncodingException e) {
-                    LOG.error("", e);
-                }
-            }
+            String tmpPass = authEncode(pop3Config.getPassword(), POP3Properties.getInstance().getPOP3AuthEnc());
             /*
              * Check for already failed authentication
              */
@@ -380,6 +382,14 @@ public final class POP3StoreConnector {
             String capabilities = staticCapabilities;
             try {
                 pop3Store.connect(server, port, login, tmpPass);
+
+                // Log connect
+                AuditLogService auditLogService = getServiceRegistry().getOptionalService(AuditLogService.class);
+                if (null != auditLogService) {
+                    String eventId = MailAccount.DEFAULT_ID == accountId ? "pop3.primary.login" : "pop3.external.login";
+                    auditLogService.log(eventId, DefaultAttribute.valueFor(Name.LOGIN, session.getLoginName()), DefaultAttribute.valueFor(Name.IP_ADDRESS, session.getLocalIp()), DefaultAttribute.timestampFor(new Date()), DefaultAttribute.arbitraryFor("pop3.login", pop3Config.getLogin()), DefaultAttribute.arbitraryFor("pop3.server", server), DefaultAttribute.arbitraryFor("pop3.port", Integer.toString(port)));
+                }
+
                 // Fetch capabilities again
                 final Map<String, String> caps = pop3Store.reinitCapabilities();
                 if (!caps.isEmpty()) {
@@ -412,9 +422,9 @@ public final class POP3StoreConnector {
                 if (responseCodeAware && e.getMessage().indexOf("[LOGIN-DELAY]") >= 0) {
                     final int seconds = parseLoginDelaySeconds(capabilities);
                     if (-1 == seconds) {
-                        throw POP3ExceptionCode.LOGIN_DELAY.create(e, server, login, Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e.getMessage());
+                        throw POP3ExceptionCode.LOGIN_DELAY.create(e, server, pop3Config.getLogin(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e.getMessage());
                     }
-                    throw POP3ExceptionCode.LOGIN_DELAY2.create(e, server, login, Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), Integer.valueOf(seconds), e.getMessage());
+                    throw POP3ExceptionCode.LOGIN_DELAY2.create(e, server, pop3Config.getLogin(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), Integer.valueOf(seconds), e.getMessage());
                 }
                 throw e;
             } catch (final MessagingException e) {
@@ -454,13 +464,13 @@ public final class POP3StoreConnector {
                         if (errorOnMissingUIDL) {
                             throw POP3ExceptionCode.MISSING_REQUIRED_CAPABILITY.create("UIDL",
                                 server,
-                                login,
+                                pop3Config.getLogin(),
                                 Integer.valueOf(session.getUserId()),
                                 Integer.valueOf(session.getContextId()));
                         }
                         result.addWarning(POP3ExceptionCode.EXPUNGE_MODE_ONLY.create("UIDL",
                             server,
-                            login,
+                            pop3Config.getLogin(),
                             Integer.valueOf(session.getUserId()),
                             Integer.valueOf(session.getContextId())));
                     }
@@ -471,7 +481,7 @@ public final class POP3StoreConnector {
                          */
                         throw POP3ExceptionCode.MISSING_REQUIRED_CAPABILITY.create("TOP",
                             server,
-                            login,
+                            pop3Config.getLogin(),
                             Integer.valueOf(session.getUserId()),
                             Integer.valueOf(session.getContextId()));
                     }
@@ -636,4 +646,17 @@ public final class POP3StoreConnector {
         }
     }
 
+    private static String authEncode(String s, String charset) {
+        String tmp = s;
+        if (tmp != null) {
+            try {
+                tmp = new String(s.getBytes(Charsets.forName(charset)), Charsets.ISO_8859_1);
+            } catch (final UnsupportedCharsetException e) {
+                LOG.error("Unsupported encoding in a message detected and monitored", e);
+                mailInterfaceMonitor.addUnsupportedEncodingExceptions(e.getMessage());
+            }
+        }
+        return tmp;
+    }
+
 }
