@@ -55,10 +55,12 @@ import java.util.Hashtable;
 import org.osgi.framework.BundleActivator;
 import com.openexchange.caching.CacheService;
 import com.openexchange.capabilities.CapabilityService;
+import com.openexchange.charset.CharsetService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.groupware.settings.PreferencesItemService;
+import com.openexchange.log.audit.AuditLogService;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -68,6 +70,7 @@ import com.openexchange.pop3.POP3Provider;
 import com.openexchange.pop3.storage.POP3StorageProvider;
 import com.openexchange.pop3.storage.mailaccount.MailAccountPOP3StorageProvider;
 import com.openexchange.sessiond.SessiondService;
+import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
 import com.openexchange.user.UserService;
 
@@ -94,7 +97,7 @@ public final class POP3Activator extends HousekeepingActivator {
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
             ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class,
-            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class
+            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class, ThreadPoolService.class, CharsetService.class
         };
     }
 
@@ -147,6 +150,7 @@ public final class POP3Activator extends HousekeepingActivator {
              */
             track(POP3StorageProvider.class, customizer);
             track(SessiondService.class);
+            trackService(AuditLogService.class);
             openTrackers();
             /*
              * Register
