@@ -424,6 +424,11 @@ public class MailAccountPOP3MessageStorage implements ISimplifiedThreadStructure
         return delegatee.saveDraft(getRealFullname(draftFullname), draftMail);
     }
 
+    @Override
+    public int getUnreadCount(final String folder, final SearchTerm<?> searchTerm) throws OXException {
+        return delegatee.getUnreadCount(folder, searchTerm);
+    }
+
     @Override
     public MailMessage[] searchMessages(final String folder, final IndexRange indexRange, final MailSortField sortField, final OrderDirection order, final SearchTerm<?> searchTerm, final MailField[] fields) throws OXException {
         final MailMessage[] mails = delegatee.searchMessages(getRealFullname(folder), indexRange, sortField, order, searchTerm, fields);
@@ -462,6 +467,11 @@ public class MailAccountPOP3MessageStorage implements ISimplifiedThreadStructure
         delegatee.updateMessageFlags(getRealFullname(folder), mailIds, flags, set);
     }
 
+    @Override
+    public void updateMessageFlags(final String folder, final String[] mailIds, final int flags, String[] userFlags, final boolean set) throws OXException {
+        delegatee.updateMessageFlags(getRealFullname(folder), mailIds, flags, userFlags, set);
+    }
+
     @Override
     public MailMessage[] getDeletedMessages(final String folder, final MailField[] fields) throws OXException {
         final MailMessage[] mails = delegatee.getDeletedMessages(folder, fields);
