@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,6 +65,7 @@ import com.openexchange.pop3.storage.POP3Storage;
 import com.openexchange.pop3.storage.mailaccount.RdbPOP3StorageProperties;
 import com.openexchange.pop3.storage.mailaccount.RdbPOP3StorageTrashContainer;
 import com.openexchange.pop3.storage.mailaccount.RdbPOP3StorageUIDLMap;
+import com.openexchange.pop3.storage.mailaccount.SessionParameterNames;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.tools.sql.DBUtils;
@@ -126,13 +127,19 @@ public final class StorageDeleteListener implements MailAccountDeleteListener {
             /*
              * Delete storage content for user if a valid session can be found
              */
-            final SessiondService sessiondService = POP3ServiceRegistry.getServiceRegistry().getService(SessiondService.class);
+            SessiondService sessiondService = POP3ServiceRegistry.getServiceRegistry().getService(SessiondService.class);
             if (null != sessiondService) {
-                final Session session = sessiondService.getAnyActiveSessionForUser(user, cid);
-                if (session != null) {
+                for (Session session : sessiondService.getSessions(user, cid)) {
                     final POP3Access pop3Access = POP3Access.newInstance(session, id);
                     final POP3Storage pop3Storage = pop3Access.getPOP3Storage();
                     pop3Storage.drop();
+
+                    String key = SessionParameterNames.getStorageProperties(id);
+                    session.setParameter(key, null);
+                    key = SessionParameterNames.getTrashContainer(id);
+                    session.setParameter(key, null);
+                    key = SessionParameterNames.getUIDLMap(cid);
+                    session.setParameter(key, null);
                 }
             }
             /*
